Enum bincode::rustc_serialize::EncodingError
[−]
[src]
pub enum EncodingError {
IoError(IoError),
SizeLimit,
}An error that can be produced during encoding.
Variants
IoError(IoError)An error originating from the underlying Writer.
SizeLimitAn object could not be encoded with the given size limit.
This error is returned before any bytes are written to the
output Writer.